@@ -1,19 +1,27 @@
 from .CameraContext import CameraContext
 from .GraphComponent import GraphComponent
 from .JsonView import JsonView
+from .MatSidebar import MatSidebar
 from .PeriodicContext import PeriodicContext
+from .PeriodicContextTable import PeriodicContextTable
 from .PeriodicElement import PeriodicElement
 from .PeriodicFilter import PeriodicFilter
 from .PeriodicTableInput import PeriodicTableInput
+from .Search import Search
+from .SearchGrid import SearchGrid
 from .Simple3DScene import Simple3DScene
 
 __all__ = [
     "CameraContext",
     "GraphComponent",
     "JsonView",
+    "MatSidebar",
     "PeriodicContext",
+    "PeriodicContextTable",
     "PeriodicElement",
     "PeriodicFilter",
     "PeriodicTableInput",
+    "Search",
+    "SearchGrid",
     "Simple3DScene"
 ]
\ No newline at end of file
